@@ -101,6 +101,7 @@ func NewAuthenticationOperator(
 	authOpConfigClient OperatorClient,
 	oauthClientClient oauthclient.OauthV1Interface,
 	kubeInformersNamespaced informers.SharedInformerFactory,
+	kubeSystemNamespaceInformers informers.SharedInformerFactory,
 	kubeClient kubernetes.Interface,
 	routeInformer routeinformer.RouteInformer,
 	routeClient routeclient.RouteV1Interface,
@@ -156,6 +157,7 @@ func NewAuthenticationOperator(
 	configV1Informers := configInformers.Config().V1()
 
 	targetNameFilter := operator.FilterByNames("oauth-openshift")
+	kubeadminNameFilter := operator.FilterByNames("kubeadmin")
 	configNameFilter := operator.FilterByNames("cluster")
 	prefixFilter := getPrefixFilter()
 
@@ -167,6 +169,8 @@ func NewAuthenticationOperator(
 		operator.WithInformer(coreInformers.Secrets(), prefixFilter),
 		operator.WithInformer(coreInformers.ConfigMaps(), prefixFilter),
 
+		operator.WithInformer(kubeSystemNamespaceInformers.Core().V1().Secrets(), kubeadminNameFilter),
+
 		operator.WithInformer(authOpConfigClient.Informers.Operator().V1().Authentications(), configNameFilter),
 		operator.WithInformer(configV1Informers.Authentications(), configNameFilter),
 		operator.WithInformer(configV1Informers.OAuths(), configNameFilter),
@@ -339,9 +343,7 @@ func (c *authOperator) handleSync(operatorConfig *operatorv1.Authentication) err
 	expectedDeployment := defaultDeployment(
 		operatorConfig,
 		syncData,
-		routerSecret,
 		proxyConfig,
-		operatorDeployment,
 		resourceVersions...,
 	)
 
